@@ -431,6 +431,18 @@ EVENT(garbage_collect)
 		loop.do_garbage_collect = 0;
 }
 
+EVENT(deprecated_notice)
+{
+	/* Send a warning to opers currently online every week after November 1, 2016 */
+	if (TStime() > 1477954800)
+	{
+		sendto_realops("[WARNING] UnrealIRCd 3.2.x is no longer supported after December 31, 2016. "
+					   "See https://www.unrealircd.org/docs/UnrealIRCd_3.2.x_deprecated");
+		ircd_log(LOG_ERROR, "[WARNING] UnrealIRCd 3.2.x is no longer supported after December 31, 2016. "
+		               "See https://www.unrealircd.org/docs/UnrealIRCd_3.2.x_deprecated");
+	}
+}
+
 /*
 ** try_connections
 **
@@ -1531,6 +1543,11 @@ int InitwIRCD(int argc, char *argv[])
 	fprintf(stderr,
 	    "---------------------------------------------------------------------\n");
 #endif
+	if (time(NULL) > 1459461600)
+	{
+		fprintf(stderr, "WARNING: UnrealIRCd 3.2.x is no longer supported after December 31, 2016.\n"
+		                "See https://www.unrealircd.org/docs/UnrealIRCd_3.2.x_deprecated\n");
+	}
 	open_debugfile();
 #ifndef NO_FDLIST
 	init_fdlist(&serv_fdlist);
