@@ -513,8 +513,13 @@ char *xtok = show_change ? TOK_SVS2MODE : TOK_SVSMODE;
 					IRCstats.operators++;
 				goto setmodex;
 			case 'd':
-				if (parv[3] && isdigit(*parv[3]))
-					acptr->user->servicestamp = strtoul(parv[3], NULL, 10);
+				if (parv[3])
+				{
+					strlcpy(acptr->user->svid, parv[3], sizeof(acptr->user->svid));
+					sendto_common_channels_local_butone(acptr, PROTO_ACCOUNT_NOTIFY, ":%s ACCOUNT %s",
+									    acptr->name,
+									    !isdigit(*acptr->user->svid) ? acptr->user->svid : "*");
+				}
 				break;
 			case 'x':
 				if (what == MODE_DEL)
