@@ -2138,20 +2138,27 @@ deadsocket:
 		}
 		length = 1;	/* for fall through case */
 
-#ifdef USE_POLL
-		if (pfd->revents & POLLIN)
-#else
-		if (FD_ISSET(cptr->fd, &read_set))
+                if (!DoingDNS(cptr) && !DoingAuth(cptr)
+#ifdef USE_SSL
+                    && !IsSSLHandshake(cptr)
 #endif
-			length = read_packet(cptr, 1);
-		/* If we don't have anything to read and we have any recvQ, then
-		 * read_packet must still be called, but this time with the 2nd parameter
-		 * being 0 (=don't read). This is so we check if anything needs to
-		 * be dequeued from the receive queue (due to fake lag). -- Syzop
-		 */
-		else if (DBufLength(&cptr->recvQ) > 0)
-			length = read_packet(cptr, 0);
-
+                    )
+                {
+#ifdef USE_POLL
+        		if (pfd->revents & POLLIN)
+#else
+	        	if (FD_ISSET(cptr->fd, &read_set))
+#endif
+        			length = read_packet(cptr, 1);
+        		/* If we don't have anything to read and we have any recvQ, then
+	        	 * read_packet must still be called, but this time with the 2nd parameter
+        		 * being 0 (=don't read). This is so we check if anything needs to
+	        	 * be dequeued from the receive queue (due to fake lag). -- Syzop
+        		 */
+	        	else if (DBufLength(&cptr->recvQ) > 0)
+        			length = read_packet(cptr, 0);
+                }
+                
 #ifdef USE_SSL
 		if ((length != FLUSH_BUFFER) && (cptr->ssl != NULL) && 
 			IsSSLHandshake(cptr) &&
@@ -2405,26 +2412,26 @@ static struct SOCKADDR *connect_inet(ConfigItem_link *aconf, aClient *cptr, int
 		return NULL;
 	}
 	mysk.SIN_PORT = 0;
-	bzero((char *)&server, sizeof(server));
-	server.SIN_FAMILY = AFINET;
+
 	get_sockhost(cptr, aconf->hostname);
-	
-	server.SIN_PORT = 0;
-	server.SIN_ADDR = me.ip;
-	server.SIN_FAMILY = AFINET;
+
 	if (aconf->bindip && strcmp("*", aconf->bindip))
 	{
+		bzero((char *)&server, sizeof(server));
+		server.SIN_FAMILY = AFINET;
+		server.SIN_PORT = 0;
 #ifndef INET6
 		server.SIN_ADDR.S_ADDR = inet_addr(aconf->bindip);	
 #else
 		inet_pton(AF_INET6, aconf->bindip, server.SIN_ADDR.S_ADDR);
 #endif
+		if (bind(cptr->fd, (struct SOCKADDR *)&server, sizeof(server)) == -1)
+		{
+			report_baderror("error binding to local port for %s:%s", cptr);
+			return NULL;
+		}
 	}
-	if (bind(cptr->fd, (struct SOCKADDR *)&server, sizeof(server)) == -1)
-	{
-		report_baderror("error binding to local port for %s:%s", cptr);
-		return NULL;
-	}
+
 	bzero((char *)&server, sizeof(server));
 	server.SIN_FAMILY = AFINET;
 	/*
